# Nabu is a simple and efficient static site generator using Markdown

Tired of `hugo`, `jekyll`, and complicated frameworks?
Just create a content folder, and use `nabu` to create HTML pages based on a template of your choice. The table of contents will be automatically generated for you.